@@ -43,7 +43,8 @@
 #' @param gr Logical argument to add grid to spectrogram. Default is \code{FALSE}.
 #' @param sc Logical argument to add amplitude scale to spectrogram, default is 
 #'   \code{FALSE}.
-#' @param line Logical argument to add red lines at start and end times of selection. Default is \code{TRUE}.
+#' @param line Logical argument to add red lines at start and end times of selection 
+#' (or box if low.f and high.f columns are provided). Default is \code{TRUE}.
 #' @param mar Numeric vector of length 1. Specifies the margins adjacent to the start and end points of selections, 
 #' dealineating spectrogram limits. Default is 0.05.
 #' @param it A character vector of length 1 giving the image type to be used. Currently only
@@ -70,13 +71,13 @@
 #' # First set empty folder
 #' setwd(tempdir())
 
-#' data(list = c("Phae.long1", "Phae.long2","manualoc.df"))
+#' data(list = c("Phae.long1", "Phae.long2","selec.table"))
 #' writeWave(Phae.long1, "Phae.long1.wav") #save sound files 
 #' writeWave(Phae.long2, "Phae.long2.wav")
 #' 
 #' # make spectrograms
 #' 
-#' specreator(manualoc.df, flim = c(0, 11), res = 300, mar = 0.05, wl = 300)
+#' specreator(selec.table, flim = c(0, 11), res = 300, mar = 0.05, wl = 300)
 #'  
 #'  #' #check this folder!!
 #' getwd()
@@ -125,7 +126,7 @@ specreator <- function(X, wl = 512, flim = c(0, 22), wn = "hanning", pal = rever
   if(it == "jpeg") imgfun <- jpeg else imgfun <- tiff
   
   #return warning if not all sound files were found
-  recs.wd <- list.files(pattern = ".wav$", ignore.case = TRUE)
+  recs.wd <- list.files(pattern = "\\.wav$", ignore.case = TRUE)
   if(length(unique(X$sound.files[(X$sound.files %in% recs.wd)])) != length(unique(X$sound.files))) 
     (paste(length(unique(X$sound.files))-length(unique(X$sound.files[(X$sound.files %in% recs.wd)])), 
            ".wav file(s) not found"))
@@ -198,9 +199,13 @@ specreator <- function(X, wl = 512, flim = c(0, 22), wn = "hanning", pal = rever
         title(paste(X$sound.files[i], "-", X$selec[i], sep = ""), cex.main = cexlab)
     
     # Plot lines to visualize selections (start and end of signal)
-      if(line)    
-        abline(v = c(mar1, mar2), col = "red", lwd = 3, lty = "dashed")
-    invisible() # execute par(old.par) 
+    if(line){  
+      if(any(names(X) == "low.f") & any(names(X) == "high.f"))
+      {   if(!is.na(X$low.f[i]) & !is.na(X$high.f[i]))
+        polygon(x = rep(c(mar1, mar2), each = 2), y = c(X$low.f[i], X$high.f[i], X$high.f[i], X$low.f[i]), lty = 3, border = "blue", lwd = 1.2, col = adjustcolor("blue", alpha.f = 0.05)) else
+          abline(v = c(mar1, mar2), col= "red", lty = "dashed")
+      } else abline(v = c(mar1, mar2), col= "red", lty = "dashed")
+    }  
     dev.off()
   }
 
